@@ -2,7 +2,7 @@ from itertools import product
 
 from pandas import DataFrame, Series
 from scipy.stats import beta as beta_dist, rv_continuous
-from typing import List, Union
+from typing import List, Union, Optional
 
 from probability.distributions.mixins.rv_continuous_1d_mixin import RVContinuous1dMixin
 from probability.distributions.special import prob_bb_greater_exact
@@ -52,7 +52,8 @@ class Beta(RVContinuous1dMixin):
     def from_data_frame(
             data: DataFrame,
             prob_vars: Union[str, List[str]],
-            cond_vars: Union[str, List[str]]
+            cond_vars: Union[str, List[str]],
+            stats: Optional[Union[str, List[str]]] = None
     ) -> DataFrame:
         """
         Return a dict mapping probability and conditional variables to Beta
@@ -61,6 +62,10 @@ class Beta(RVContinuous1dMixin):
         :param data: DataFrame containing discrete data.
         :param prob_vars: Names of binary variables to find probability of.
         :param cond_vars: Names of discrete variables to condition on.
+                          Calculations will be done for the cartesian product
+                          of values in each variable.
+        :param stats: Optional stats to append to the output e.g. 'alpha',
+                      'median'.
         :return: DataFrame with columns for each conditioning variable, a 'p'
                  column indicating the probability variable and a 'Beta'
                  column containing the distribution.
@@ -69,12 +74,12 @@ class Beta(RVContinuous1dMixin):
             prob_vars = [prob_vars]
         if isinstance(cond_vars, str):
             cond_vars = [cond_vars]
-        cond_combos = product(
+        cond_products = product(
             *[data[cond_var].unique() for cond_var in cond_vars]
         )
         betas = []
         # iterate over conditions
-        for cond_values in cond_combos:
+        for cond_values in cond_products:
             cond_data = data
             cond_dict = {}
             for cond_var, cond_value in zip(cond_vars, cond_values):
@@ -89,7 +94,21 @@ class Beta(RVContinuous1dMixin):
                     alpha=m_prob, beta=n_cond - m_prob
                 )
                 betas.append(prob_dict)
-        return DataFrame(betas)
+        betas_data = DataFrame(betas)
+        if stats is not None:
+            if isinstance(stats, str):
+                stats = [stats]
+                for stat in stats:
+                    if hasattr(Beta, stat):
+                        if callable(getattr(Beta, stat)):
+                            betas_data[stat] = betas_data['Beta'].map(
+                                lambda b: getattr(b, stat)()
+                            )
+                        else:
+                            betas_data[stat] = betas_data['Beta'].map(
+                                lambda b: getattr(b, stat)
+                            )
+        return betas_data
 
     def __str__(self):
 
@@ -106,6 +125,6 @@ class Beta(RVContinuous1dMixin):
             alpha_2=other._alpha, beta_2=other._beta, m_2=0, n_2=0
         )
 
-    def __lt__(self, other: 'RVS1dMixin') -> float:
+    def __lt__(self, other: 'Beta') -> float:
 
         return other < self
